Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(585)

Unified Diff: chrome/renderer/extensions/bindings_utils.h

Issue 113085: Split V8Proxy::retrieveActiveFrame() into two methods. (Closed)
Patch Set: Darin feedback Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/renderer/extensions/bindings_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/extensions/bindings_utils.h
diff --git a/chrome/renderer/extensions/bindings_utils.h b/chrome/renderer/extensions/bindings_utils.h
index 7f336c32d4673295bf22d3bdb2ec2e145b869c42..7596952bbdc8cfbe777af65253e06ff8b59d5b4a 100755
--- a/chrome/renderer/extensions/bindings_utils.h
+++ b/chrome/renderer/extensions/bindings_utils.h
@@ -28,8 +28,8 @@ const char* GetStringResource() {
Singleton< StringResourceTemplate<kResourceId> >::get()->resource.c_str();
}
// Returns the active RenderView, based on which V8 context is active. It is
// an error to call this when not in a V8 context.
-RenderView* GetActiveRenderView();
+RenderView* GetRenderViewForCurrentContext();
#endif // CHROME_RENDERER_EXTENSIONS_BINDINGS_UTILS_H_
« no previous file with comments | « no previous file | chrome/renderer/extensions/bindings_utils.cc » ('j') | no next file with comments »
@@ -28,8 +28,8 @@ const char* GetStringResource() {
Singleton< StringResourceTemplate<kResourceId> >::get()->resource.c_str();
}
-// Returns the active RenderView, based on which V8 context is active. It is
+// Returns the current RenderView, based on which V8 context is current. It is
// an error to call this when not in a V8 context.

Powered by Google App Engine
This is Rietveld 408576698